TencentCloudChatDesktopImageTools class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

captureScreen() → Future<String?>
getImageSize(String imagePath) → Future<Size>
requestScreenRecordingPermission() → Future<bool>
sendImageOnDesktop({Size? imageSize, required BuildContext context, required String imagePath, String? imageName, dynamic inputElement, required String currentConversationShowName, required dynamic sendImageMessage({String? imageName, String? imagePath, dynamic inputElement})}) → dynamic